Usefull methods for simple web parsing :

* Using requests for open url and accessing page
* Simple history management
* Download ressource
* Simple way to get html elements as string with css selectors
* Open the current page in your default browser
* Simple way to follow links
* Simple form management

Github repository : `https://github.com/karec/oct-browser`_

.. _https://github.com/karec/oct-browser: https://github.com/karec/oct-browser

Documentation : `http://octbrowser.readthedocs.org/en/latest/index.html`_

.. _http://octbrowser.readthedocs.org/en/latest/index.html: http://octbrowser.readthedocs.org/en/latest/index.html

